@@ -1,5 +1,6 @@
 /*
- * LALBurstVCSInfo.h - LALBurst VCS Information Header
+ * Copyright (C) 2014, 2016 Karl Wette
+ * Copyright (C) 2009-2013 Adam Mercer
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -15,9 +16,10 @@
  * along with with program; see the file COPYING. If not, write to the
  * Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
  * MA 02111-1307 USA
- *
- * Copyright (C) 2009-2013 Adam Mercer
- * Copyright (C) 2014 Karl Wette
+ */
+
+/*
+ * LALBurstVCSInfo.h - LALBurst VCS Information Header
  */
 
 /** \cond DONT_DOXYGEN */
@@ -33,37 +35,19 @@
 extern "C" {
 #endif
 
-/* VCS information defines */
-#define LALBURST_NAME "LALBurst"
-#define LALBURST_VCS_ID "11dae2552f6d19c2698b9fc496225ca15384fda5"
-#define LALBURST_VCS_DATE "2016-10-10 17:31:35 +0000"
+/* VCS information */
+#define LALBURST_VCS_ID "ceb24bb3ed0985021af5f2d04b2bc7b9481abf53"
+#define LALBURST_VCS_DATE "2017-02-6 18:16:00 +0000"
 #define LALBURST_VCS_BRANCH "None"
-#define LALBURST_VCS_TAG "lalburst-v1.4.3"
+#define LALBURST_VCS_TAG "lalburst-v1.4.4"
 #define LALBURST_VCS_AUTHOR "Adam Mercer <adam.mercer@ligo.org>"
 #define LALBURST_VCS_COMMITTER "Adam Mercer <adam.mercer@ligo.org>"
+#define LALBURST_VCS_CLEAN "CLEAN"
 #define LALBURST_VCS_STATUS "CLEAN: All modifications committed"
 
-/* Identable VCS information defines */
-#define LALBURST_VCS_IDENT_ID "$" "LALBurstId: 11dae2552f6d19c2698b9fc496225ca15384fda5 " "$"
-#define LALBURST_VCS_IDENT_DATE "$" "LALBurstDate: 2016-10-10 17:31:35 +0000 " "$"
-#define LALBURST_VCS_IDENT_BRANCH "$" "LALBurstBranch: None " "$"
-#define LALBURST_VCS_IDENT_TAG "$" "LALBurstTag: lalburst-v1.4.3 " "$"
-#define LALBURST_VCS_IDENT_AUTHOR "$" "LALBurstAuthor: Adam Mercer <adam.mercer@ligo.org> " "$"
-#define LALBURST_VCS_IDENT_COMMITTER "$" "LALBurstCommitter: Adam Mercer <adam.mercer@ligo.org> " "$"
-#define LALBURST_VCS_IDENT_STATUS "$" "LALBurstStatus: CLEAN: All modifications committed " "$"
-
-/* Header VCS information structure */
-static const LALVCSInfo lalBurstVCSInfoHeader = { \
-  LALBURST_NAME, \
-  LALBURST_VERSION, \
-  LALBURST_VCS_ID, \
-  LALBURST_VCS_DATE, \
-  LALBURST_VCS_BRANCH, \
-  LALBURST_VCS_TAG, \
-  LALBURST_VCS_AUTHOR, \
-  LALBURST_VCS_COMMITTER, \
-  LALBURST_VCS_STATUS \
-};
+/* VCS header/library mismatch link check function */
+#define LALBURST_VCS_LINK_CHECK LALBURST_CLEAN_ceb24bb3ed0985021af5f2d04b2bc7b9481abf53_VCS_HEADER_LIBRARY_MISMATCH
+void LALBURST_VCS_LINK_CHECK(void);
 
 #ifdef __cplusplus
 }
@@ -72,7 +56,3 @@ static const LALVCSInfo lalBurstVCSInfoHeader = { \
 #endif /* _LALBURSTVCSINFOHEADER_H */
 
 /** \endcond */
-
-/*
- * vim: tw=0 ts=2 et
- */
